@@ -59,7 +59,7 @@ class Database {
                         updatetime DATETIME NOT NULL,
                         author VARCHAR(255),
                         INDEX (source)
-                    ) ENGINE = MYISAM DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
                 ');
                 \F3::get('db')->exec('
                     CREATE TRIGGER insert_updatetime_trigger
@@ -88,8 +88,9 @@ class Database {
                         params TEXT NOT NULL ,
                         filter TEXT,
                         error TEXT,
-                        lastupdate INT
-                    ) ENGINE = MYISAM DEFAULT CHARSET=utf8;
+                        lastupdate INT,
+                		lastentry INT
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
                 ');
                 $isNewestSourcesTable = true;
             }
@@ -99,18 +100,18 @@ class Database {
                 \F3::get('db')->exec('
                     CREATE TABLE '.\F3::get('db_prefix').'version (
                         version INT
-                    ) ENGINE = MYISAM DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
                 ');
                 
                 \F3::get('db')->exec('
-                    INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (6);
+                    INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (8);
                 ');
                 
                 \F3::get('db')->exec('
                     CREATE TABLE '.\F3::get('db_prefix').'tags (
                         tag         TEXT NOT NULL,
                         color       VARCHAR(7) NOT NULL
-                    ) ENGINE = MYISAM DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
                 ');
                 
                 if($isNewestSourcesTable===false) {
@@ -169,6 +170,17 @@ class Database {
                         INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (6);
                     ');
                 }
+                // Jump straight from v6 to v8 due to bug in previous version of the code
+                // in /daos/sqlite/Database.php which
+                // set the database version to "7" for initial installs.
+                if(strnatcmp($version, "8") < 0){
+                	\F3::get('db')->exec('
+                        ALTER TABLE '.\F3::get('db_prefix').'sources ADD lastentry INT;
+                    ');
+                	\F3::get('db')->exec('
+                        INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (8);
+                    ');
+                }
             }
             
             // just initialize once
