@@ -20,6 +20,7 @@ $js=array(
     'public/js/spectrum.js',
     'public/js/jquery.hotkeys.js',
     'public/js/selfoss-base.js',
+    'public/js/selfoss-shares.js',
     'public/js/selfoss-events.js',
     'public/js/selfoss-events-navigation.js',
     'public/js/selfoss-events-search.js',
@@ -79,6 +80,7 @@ $f3->route('GET    /source/params',     'controllers\Sources->params');       //
 $f3->route('GET    /sources',           'controllers\Sources->show');         // html
 $f3->route('GET    /source',            'controllers\Sources->add');          // html
 $f3->route('GET    /sources/list',      'controllers\Sources->listSources');  // json
+$f3->route('GET    /sources/stats',     'controllers\Sources->sourcesStats');  // json
 $f3->route('POST   /source/@id',        'controllers\Sources->write');        // json
 $f3->route('POST   /source',            'controllers\Sources->write');        // json
 $f3->route('DELETE /source/@id',        'controllers\Sources->remove');       // json
